==> nextcloud-28.0.7.tgz: nextcloud/apps/settings/l10n/az.js <==
OC.L10N.register(
    "settings",
    {
    "Private" : "Gizli",
    "Local" : "Yerli",
    "Federated" : "Federated",
    "Published" : "Nəşr edilmiş",
    "Verify" : "Təsdiq et",
    "Verifying …" : "Təsdiqlənir ...",
    "Unable to change password" : "Şifrəni dəyişmək olmur",
    "Very weak password" : "Çox asan şifrə",
    "Weak password" : "Asan şifrə",
    "So-so password" : "Elə-belə şifrə",
    "Good password" : "Yaxşı şifrə",
    "Strong password" : "Çətin şifrə",
    "Groups" : "Qruplar",
    "Group list is empty" : "Qrup listi boşdur",
    "Your password was reset" : "Sizin parol yeniləndi",
    "You changed your email address" : "Siz email ünvanınızı dəyişdir",
    "Settings" : "Quraşdırmalar",
    "Could not remove app." : "Tətbiqi silmək olmur.",
    "Could not update app." : "Tətbiqi yeniləmək alınmır",
    "Wrong password" : "Yalnış şifrə",
    "Unable to change personal password" : "Şəxsi parolu dəyişmək alınmadı",
    "Saved" : "Saxlanıldı",
    "Unable to change password. Password too long." : "Parolu dəyişmək alınmadı. Parol çox uzundur.",
    "Authentication error" : "Təyinat metodikası",
    "Wrong admin recovery password. Please check the password and try again." : "İnzibatçı geriyə qayıdış şifrəsi yalnışdır. Xahiş olunur şifrəni yoxlayıb yenidən təkrar edəsiniz.",
    "User documentation" : "İstifadəçi dokumentasiyası",
    "Invalid SMTP password." : "SMTP parol səhvdir",
    "Email setting test" : "Email parametrləriinin testi",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Məktubun yollanmasında səhv baş verdi. Xahiş olunur öz quraşdırmalarınıza yenidən göz yetirəsiniz.(Error: %s)",
    "Invalid mail address" : "Yalnış mail ünvanı",
    "Settings saved" : "Parametrlər yaddaşa verildi",
    "Unable to change full name" : "Tam adı dəyişmək olmur",
    "Your %s account was created" : "Sizin %s hesab yaradıldı",
    "Welcome aboard" : "Xoş gəlmisiniz!",
    "Welcome aboard %s" : "%s-a xoş gəlmisiniz",
    "Set your password" : "Parolunuzu təyin edin",
    "Install Client" : "Müştərini Quraşdır",
    "Apps" : "Tətbiqlər",
    "Personal" : "Şəxsi",
    "Administration" : "İdarəetmə",
    "Users" : "İstifadəçilər",
    "Additional settings" : "Əlavə parametrlər",
    "Overview" : "İcmal",
    "Basic settings" : "İlkin parametrlər",
    "Sharing" : "Paylaşılır",
    "Availability" : "Əlçatanlıq",
    "Calendar" : "Təqvim",
    "Personal info" : "Şəxsi məlumat",
    "Mobile & desktop" : "Mobil & Desktop",
    "Email server" : "Email server",
    "Security & setup warnings" : "Təhlükəsizlik & işə salma xəbərdarlıqları",
    "Background jobs" : "Background işlər",
    "Unlimited" : "Limitsiz",
    "Verifying" : "Təsdiqlənir",
    "Disabled" : "Dayandırılıb",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "Server tərəfdən köhnə şifrələnmə formatı aktivdir. Onu söndürməyi tövsiyyə edirik.",
    "Supported" : "Dəstəklənir",
    "Profile information" : "Profil məlumatı",
    "Nextcloud settings" : "Nextcloud parametrləri",
    "None" : "Heç bir",
    "Unable to modify setting" : "Xassələri yeniləmək olmadı",
    "Allow apps to use the Share API" : "Proqramlara izin verin ki, Paylaşım API-sindən istifadə edə bilsinlər.",
    "Allow resharing" : "Yenidən paylaşıma izin",
    "Restrict users to only share with users in their groups" : "İstifadəçiləri yalnız yerləşdikləri qrup üzvləri ilə paylaşım edə bilmələrini məhdudla",
    "Allow public uploads" : "Ümumi yüklənmələrə izin vermək",
    "Enforce password protection" : "Şifrə müdafiəsini həyata keçirmək",
    "Enforce expiration date" : "Bitmə tarixini həyata keçir",
    "Two-Factor Authentication" : "İki faktorlu autentifikasiya",
    "Limit to groups" : "Qruplara limitlə",
    "Save changes" : "Dəyişiklikləri yaddaşa ver",
    "Remove" : "Sil",
    "Disable" : "Dayandır",
    "Featured" : "Seçilmiş",
    "Name" : "Ad",
    "Version" : "Versiya",
    "Actions" : "İşlər",
    "No apps found for your version" : "Sizin versiya üçün proqram tapılmadı",
    "Description" : "Açıqlanma",
    "Details" : "Detallar",
    "All" : "Hamısı",
    "Limit app usage to groups" : "Tətbiqin istifadəsini qruplar üçün limitlə",
    "No results" : "Nəticə yoxdur",
    "Update to {version}" : "{version} dək yenilə",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Bu proqram yüklənə bilməz ona görə ki, göstərilən asılılıqlar yerinə yetirilməyib:",
    "Categories" : "Kateqoriyalar",
    "Resources" : "Resurslar",
    "Documentation" : "Sənədlər",
    "Report a bug" : "Səhv haqqında bildir",
    "View in store" : "Dükanda bax",
    "Visit website" : "Sayta keç",
    "Admin documentation" : "İdarəci dokumentasiyası",
    "Developer documentation" : "Yaradıcı sənədləşməsi",
    "Changelog" : "Dəyişikliklər jurnalı",
    "Device settings" : "Cihazın parametrləri",
    "Rename" : "Adı dəyiş",
    "Wipe device" : "Cihazı silin",
    "Google Chrome for Android" : "Android üçün Google Chrome",
    "{productName} iOS app" : "{productName} iOS tətbiq",
    "{productName} Android app" : "{productName} Android tətbiq",
    "{productName} Talk for iOS" : "{productName} iOS üçün danış",
    "{productName} Talk for Android" : "{productName} Android üçün danış",
    "This session" : "Bu sessiya",
    "Device" : "Cihaz",
    "Last activity" : "Son aktivlik",
    "Devices & sessions" : "Cihaz & sessiyalar",
    "App name" : "Tətbiqin adı",
    "Create new app password" : "Yeni tətbiq parolu yaradın",
    "Login" : "Giriş",
    "Password" : "Şifrə",
    "Show QR code for mobile apps" : "Mobil tətbiqlər üçün QR kodu göstərin",
    "Last job ran {relativeTime}." : "Son işin icra vaxtı {relativeTime}.",
    "AJAX" : "AJAX",
    "Webcron" : "Webcron",
    "Cron (Recommended)" : "Cron (Tövsiyyə edilən)",
    "Profile" : "Profil",
    "Enable" : "İşə sal",
    "Cancel" : "Dayandır",
    "Confirm" : "Təsdiq edin",
    "Rename group" : "Qrupun adını dəyiş",
    "Remove group" : "Qrupu sil",
    "Current password" : "Hazırkı şifrə",
    "New password" : "Yeni şifrə",
    "Change password" : "Şifrəni dəyiş",
    "Your profile picture" : "Sizin profil şəkliniz",
    "Upload profile picture" : "Profil şəklini yüklə",
    "Choose profile picture from Files" : "Profil şəklini Faylalrdan seçin",
    "Remove profile picture" : "Profil şəklini silin",
    "The file must be a PNG or JPG" : "Fayl PNG və ya JPG olmalıdır",
    "Set as profile picture" : "Profil şəkli kimi təyin et",
    "Please select a valid png or jpg file" : "Zəhmət olmasa düzgün png və ya jpg fayl seçin",
    "Error setting profile picture" : "Profil şəklini təyiin edən vaxtı səhv baş verdi",
    "Error saving profile picture" : "Profil şəklini saxlayan vaxtı səhv baş verdi",
    "Error removing profile picture" : "Profil şəklini silən vaxtı səhv baş verdi",
    "No email address set" : "Email ünvanı dəsti yoxdur",
    "Help translate" : "Tərcüməyə kömək",
    "Add" : "Əlavə etmək",
    "Create" : "Yarat",
    "Change" : "Dəyiş",
    "Delete" : "Sil",
    "Email" : "Email",
    "Quota" : "Norma",
    "Language" : "Dil",
    "Resend welcome email" : "Salamlama e-poçtunu yenidən göndərin",
    "Welcome mail sent!" : "Salamlama məktubu göndərildi!",
    "Done" : "Edildi",
    "Edit" : "Dəyişiklik et",
    "Send email" : "Email yolla",
    "Admins" : "İnzibatçılar",
    "Email sent" : "Məktub göndərildi",
    "Location" : "Yerləşdiyiniz ünvan",
    "Profile picture" : "Profil şəkli",
    "About" : "Haqqında",
    "Full name" : "Tam ad",
    "Updates" : "Yenilənmələr",
    "Hide" : "Gizlə",
    "Never" : "Heç vaxt",
    "Confirm wipe" : "Silməni təsdiq edin",
    "Error while updating device token name" : "Cihazın tokeninin adını yeniləyən vaxtı səhv baş verdi",
    "Error" : "Səhv",
    "Forum" : "Forum",
    "SSL" : "SSL",
    "Open documentation" : "Sənədləri aç",
    "Send mode" : "Göndərmə rejimi",
    "Encryption" : "Şifrələnmə",
    "From address" : "Ünvandan",
    "Server address" : "Server ünvanı",
    "Port" : "Port",
    "Authentication" : "Autentifikasiya",
    "Authentication required" : "Qeydiyyat tələb edilir",
    "Credentials" : "Səlahiyyətlər",
    "SMTP Password" : "SMTP Şifrəsi",
    "Save" : "Saxla",
    "Check out our blog" : "Bizim bloqa baxın",
    "Subscribe to our newsletter" : "Yeniliklərə abunə olun",
    "No user supplied" : "Heç bir istifadəçiyə mənimsədilmir",
    "Federated Cloud Sharing" : "Federal Cloud Paylaşım",
    "Invalid user" : "İstifadəçi adı yalnışdır",
    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "MariaDB \"%s\" versiyası istifadə edilir. Nextcloud 21 və yuxarı versiyaları bunu dəstəkləmir və ən azı MariaDB 10.2 və ya yuxarı versiya tələb edir.",
    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "MySQL \"%s\" versiyası istifadə edilir. Nextcloud 21 və yuxarı versiyaları bunu dəstəkləmir və ən azı MySQL 8.0 və ya MariaDB 10.2 və ya yuxarı versiya tələb edir.",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "iPhone" : "iPhone",
    "iPad" : "iPad",
    "Error while deleting the token" : "Token silinən vaxtı səhv baş verdi",
    "Username" : "İstifadəçi adı",
    "Copied!" : "Kopyalandı!",
    "Copy" : "Kopyala",
    "Your profile information" : "Sizin profil məlumatlarınız",
    "Your email address" : "Sizin email ünvanı",
    "Add a new user" : "Yeni istifadəçi əlavə edin",
    "Show Languages" : "Dilləri göstərin",
    "Show user backend" : "Daxili istifadəçini göstər",
    "Send email to new user" : "Yeni istifadəçiyə məktub yolla",
    "SMTP Username" : "SMTP İstifadəçi adı",
    "Set default expiration date" : "Susmaya görə olan bitmə vaxtını təyin edin",
    "Exclude groups from sharing" : "Qrupları paylaşımdan ayır",
    "These groups will still be able to receive shares, but not to initiate them." : "Bu qruplar paylaşımları hələdə ala biləcəklər ancaq, yarada bilməyəcəklər"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-30.0.5.tgz: nextcloud/apps/settings/l10n/az.js <==
OC.L10N.register(
    "settings",
    {
    "Private" : "Gizli",
    "Local" : "Yerli",
    "Federated" : "Federated",
    "Published" : "Nəşr edilmiş",
    "Verify" : "Təsdiq et",
    "Verifying …" : "Təsdiqlənir ...",
    "Unable to change password" : "Şifrəni dəyişmək olmur",
    "Very weak password" : "Çox asan şifrə",
    "Weak password" : "Asan şifrə",
    "So-so password" : "Elə-belə şifrə",
    "Good password" : "Yaxşı şifrə",
    "Strong password" : "Çətin şifrə",
    "Groups" : "Qruplar",
    "Group list is empty" : "Qrup listi boşdur",
    "Your password was reset" : "Sizin parol yeniləndi",
    "You changed your email address" : "Siz email ünvanınızı dəyişdir",
    "Settings" : "Quraşdırmalar",
    "Could not remove app." : "Tətbiqi silmək olmur.",
    "Could not update app." : "Tətbiqi yeniləmək alınmır",
    "Wrong password" : "Yalnış şifrə",
    "Unable to change personal password" : "Şəxsi parolu dəyişmək alınmadı",
    "Saved" : "Saxlanıldı",
    "Unable to change password. Password too long." : "Parolu dəyişmək alınmadı. Parol çox uzundur.",
    "Authentication error" : "Təyinat metodikası",
    "Wrong admin recovery password. Please check the password and try again." : "İnzibatçı geriyə qayıdış şifrəsi yalnışdır. Xahiş olunur şifrəni yoxlayıb yenidən təkrar edəsiniz.",
    "User documentation" : "İstifadəçi dokumentasiyası",
    "Invalid SMTP password." : "SMTP parol səhvdir",
    "Email setting test" : "Email parametrləriinin testi",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Məktubun yollanmasında səhv baş verdi. Xahiş olunur öz quraşdırmalarınıza yenidən göz yetirəsiniz.(Error: %s)",
    "Invalid mail address" : "Yalnış mail ünvanı",
    "Settings saved" : "Parametrlər yaddaşa verildi",
    "Unable to change full name" : "Tam adı dəyişmək olmur",
    "Your %s account was created" : "Sizin %s hesab yaradıldı",
    "Welcome aboard" : "Xoş gəlmisiniz!",
    "Welcome aboard %s" : "%s-a xoş gəlmisiniz",
    "Set your password" : "Parolunuzu təyin edin",
    "Install Client" : "Müştərini Quraşdır",
    "Apps" : "Tətbiqlər",
    "Personal" : "Şəxsi",
    "Administration" : "İdarəetmə",
    "Users" : "İstifadəçilər",
    "Additional settings" : "Əlavə parametrlər",
    "Overview" : "İcmal",
    "Basic settings" : "İlkin parametrlər",
    "Sharing" : "Paylaşılır",
    "Availability" : "Əlçatanlıq",
    "Calendar" : "Təqvim",
    "Personal info" : "Şəxsi məlumat",
    "Mobile & desktop" : "Mobil & Desktop",
    "Email server" : "Email server",
    "Background jobs" : "Background işlər",
    "Unlimited" : "Limitsiz",
    "Verifying" : "Təsdiqlənir",
    "Disabled" : "Dayandırılıb",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "Server tərəfdən köhnə şifrələnmə formatı aktivdir. Onu söndürməyi tövsiyyə edirik.",
    "Supported" : "Dəstəklənir",
    "Profile information" : "Profil məlumatı",
    "Nextcloud settings" : "Nextcloud parametrləri",
    "None" : "Heç bir",
    "Unable to modify setting" : "Xassələri yeniləmək olmadı",
    "Allow apps to use the Share API" : "Proqramlara izin verin ki, Paylaşım API-sindən istifadə edə bilsinlər.",
    "Allow resharing" : "Yenidən paylaşıma izin",
    "Restrict users to only share with users in their groups" : "İstifadəçiləri yalnız yerləşdikləri qrup üzvləri ilə paylaşım edə bilmələrini məhdudla",
    "Allow public uploads" : "Ümumi yüklənmələrə izin vermək",
    "Enforce password protection" : "Şifrə müdafiəsini həyata keçirmək",
    "Enforce expiration date" : "Bitmə tarixini həyata keçir",
    "Two-Factor Authentication" : "İki faktorlu autentifikasiya",
    "Limit to groups" : "Qruplara limitlə",
    "Save changes" : "Dəyişiklikləri yaddaşa ver",
    "Remove" : "Sil",
    "Featured" : "Seçilmiş",
    "Name" : "Ad",
    "Version" : "Versiya",
    "Actions" : "İşlər",
    "No apps found for your version" : "Sizin versiya üçün proqram tapılmadı",
    "Description" : "Açıqlanma",
    "Details" : "Detallar",
    "All" : "Hamısı",
    "Limit app usage to groups" : "Tətbiqin istifadəsini qruplar üçün limitlə",
    "No results" : "Nəticə yoxdur",
    "Update to {version}" : "{version} dək yenilə",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Bu proqram yüklənə bilməz ona görə ki, göstərilən asılılıqlar yerinə yetirilməyib:",
    "Categories" : "Kateqoriyalar",
    "Resources" : "Resurslar",
    "Documentation" : "Sənədlər",
    "Report a bug" : "Səhv haqqında bildir",
    "View in store" : "Dükanda bax",
    "Visit website" : "Sayta keç",
    "Admin documentation" : "İdarəci dokumentasiyası",
    "Developer documentation" : "Yaradıcı sənədləşməsi",
    "Changelog" : "Dəyişikliklər jurnalı",
    "Device settings" : "Cihazın parametrləri",
    "Rename" : "Adı dəyiş",
    "Wipe device" : "Cihazı silin",
    "Google Chrome for Android" : "Android üçün Google Chrome",
    "{productName} iOS app" : "{productName} iOS tətbiq",
    "{productName} Android app" : "{productName} Android tətbiq",
    "{productName} Talk for iOS" : "{productName} iOS üçün danış",
    "{productName} Talk for Android" : "{productName} Android üçün danış",
    "This session" : "Bu sessiya",
    "Device" : "Cihaz",
    "Last activity" : "Son aktivlik",
    "Devices & sessions" : "Cihaz & sessiyalar",
    "App name" : "Tətbiqin adı",
    "Create new app password" : "Yeni tətbiq parolu yaradın",
    "Login" : "Giriş",
    "Password" : "Şifrə",
    "Show QR code for mobile apps" : "Mobil tətbiqlər üçün QR kodu göstərin",
    "Last job ran {relativeTime}." : "Son işin icra vaxtı {relativeTime}.",
    "AJAX" : "AJAX",
    "Webcron" : "Webcron",
    "Cron (Recommended)" : "Cron (Tövsiyyə edilən)",
    "Profile" : "Profil",
    "Enable" : "İşə sal",
    "Cancel" : "Dayandır",
    "Confirm" : "Təsdiq edin",
    "Rename group" : "Qrupun adını dəyiş",
    "Remove group" : "Qrupu sil",
    "Current password" : "Hazırkı şifrə",
    "New password" : "Yeni şifrə",
    "Change password" : "Şifrəni dəyiş",
    "Your profile picture" : "Sizin profil şəkliniz",
    "Upload profile picture" : "Profil şəklini yüklə",
    "Choose profile picture from Files" : "Profil şəklini Faylalrdan seçin",
    "Remove profile picture" : "Profil şəklini silin",
    "The file must be a PNG or JPG" : "Fayl PNG və ya JPG olmalıdır",
    "Set as profile picture" : "Profil şəkli kimi təyin et",
    "Please select a valid png or jpg file" : "Zəhmət olmasa düzgün png və ya jpg fayl seçin",
    "Error setting profile picture" : "Profil şəklini təyiin edən vaxtı səhv baş verdi",
    "Error saving profile picture" : "Profil şəklini saxlayan vaxtı səhv baş verdi",
    "Error removing profile picture" : "Profil şəklini silən vaxtı səhv baş verdi",
    "No email address set" : "Email ünvanı dəsti yoxdur",
    "Help translate" : "Tərcüməyə kömək",
    "Add" : "Əlavə etmək",
    "Create" : "Yarat",
    "Change" : "Dəyiş",
    "Delete" : "Sil",
    "Email" : "Email",
    "Quota" : "Norma",
    "Language" : "Dil",
    "Resend welcome email" : "Salamlama e-poçtunu yenidən göndərin",
    "Welcome mail sent!" : "Salamlama məktubu göndərildi!",
    "Done" : "Edildi",
    "Edit" : "Dəyişiklik et",
    "Send email" : "Email yolla",
    "Admins" : "İnzibatçılar",
    "Email sent" : "Məktub göndərildi",
    "Location" : "Yerləşdiyiniz ünvan",
    "Profile picture" : "Profil şəkli",
    "About" : "Haqqında",
    "Full name" : "Tam ad",
    "Updates" : "Yenilənmələr",
    "Hide" : "Gizlə",
    "Disable" : "Dayandır",
    "Never" : "Heç vaxt",
    "Confirm wipe" : "Silməni təsdiq edin",
    "Error while updating device token name" : "Cihazın tokeninin adını yeniləyən vaxtı səhv baş verdi",
    "Error" : "Səhv",
    "Forum" : "Forum",
    "SSL" : "SSL",
    "Open documentation" : "Sənədləri aç",
    "Send mode" : "Göndərmə rejimi",
    "Encryption" : "Şifrələnmə",
    "From address" : "Ünvandan",
    "Server address" : "Server ünvanı",
    "Port" : "Port",
    "Authentication" : "Autentifikasiya",
    "Authentication required" : "Qeydiyyat tələb edilir",
    "Credentials" : "Səlahiyyətlər",
    "SMTP Password" : "SMTP Şifrəsi",
    "Save" : "Saxla",
    "Security & setup warnings" : "Təhlükəsizlik & işə salma xəbərdarlıqları",
    "Check out our blog" : "Bizim bloqa baxın",
    "Subscribe to our newsletter" : "Yeniliklərə abunə olun",
    "No user supplied" : "Heç bir istifadəçiyə mənimsədilmir",
    "Invalid user" : "İstifadəçi adı yalnışdır",
    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "MariaDB \"%s\" versiyası istifadə edilir. Nextcloud 21 və yuxarı versiyaları bunu dəstəkləmir və ən azı MariaDB 10.2 və ya yuxarı versiya tələb edir.",
    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "MySQL \"%s\" versiyası istifadə edilir. Nextcloud 21 və yuxarı versiyaları bunu dəstəkləmir və ən azı MySQL 8.0 və ya MariaDB 10.2 və ya yuxarı versiya tələb edir.",
    "Exclude groups from sharing" : "Qrupları paylaşımdan ayır",
    "These groups will still be able to receive shares, but not to initiate them." : "Bu qruplar paylaşımları hələdə ala biləcəklər ancaq, yarada bilməyəcəklər",
    "Username" : "İstifadəçi adı",
    "Show user backend" : "Daxili istifadəçini göstər",
    "SMTP Username" : "SMTP İstifadəçi adı"
},
"nplurals=2; plural=(n != 1);");
